.. _merger_tree:

Halo Merger Tree
================

The ``yt`` merger tree was removed as of :code:`yt-3.0`.  This
functionality can still be found in :code:`yt-2.x`.  However,
the recommended option is to use the
`ytree <http://ytree.readthedocs.io>`_ package, which can be
installed via pip:

.. code-block:: bash

    pip install ytree

For more information on ``ytree``, see the documentation
`here <http://ytree.readthedocs.io>`__.
